@@ -25,6 +25,10 @@
 #' Templ, M. and Kowarik, A. and Meindl, B. 
 #' Statistical Disclosure Control for Micro-Data Using the R Package sdcMicro. 
 #' \emph{Journal of Statistical Software}, \strong{67} (4), 1--36, 2015. \doi{10.18637/jss.v067.i04}
+#' 
+#' Templ, M. Statistical Disclosure Control for Microdata: Methods and Applications in R.
+#' \emph{Springer International Publishing}, 287 pages, 2017. ISBN 978-3-319-50272-4. \doi{10.1007/978-3-319-50272-4}
+#' \doi{10.1007/978-3-319-50272-4}
 #' @export
 #' @examples
 #' ## for objects of class sdcMicro:
@@ -51,11 +55,11 @@ definition=function(obj, var, before, after, addNA=FALSE) {
     stop("each level from the original factor must be listed only once in argument 'before'!")
   }
   ll <- levels(obj)
-  ll[ll %in% before] <- after[1]
+  ll[ll %in% before] <- after
   levels(obj) <- ll
   # add missing value (NA) to newly created level!
   if (addNA) {
-    obj[is.na(obj)] <- after[1]
+    obj[is.na(obj)] <- after
   }
   obj
 })
